@@ -1,10 +1,10 @@
 package Mojolicious::Plugin::QuickPg;
 use Mojo::Base 'Mojolicious::Plugin';
-#use Data::Dumper;
+
 use Mojo::Pg;
 use Carp;
 
-our $VERSION = '1.0';
+our $VERSION = '1.3.1';
 our $Debug = 0;
 has pg => sub { +{} };
 
@@ -107,13 +107,28 @@ sub _quick_query {
     } else {
         # INSERT (default field name = id)
         if ($type eq 'INSERT') {
-        # get primary key from table 
+        # get primary key from table
+        my $PK = 'id'; # default PK column is 'id'
         my $pkey =  $self->pg->db->query(qq{SELECT a.attname FROM pg_index i JOIN pg_attribute a ON a.attrelid = i.indrelid
                                          AND a.attnum = ANY(i.indkey) WHERE  i.indrelid = '$table_name'::regclass AND i.indisprimary
-                                         ORDER BY a.attnum DESC})->hash;
-        $sql .= ' returning ' . $pkey->{attname};
+                                         ORDER BY a.attnum DESC});
+        # if id exists in PKeys get it, else - get last elem
+        while (my $next = $pkey->hash) {
+             if ( $next->{attname} eq 'id' ) {
+                $PK = $next->{attname};
+                # Note that "finish" needs to be called if you are not fetching all the possible rows
+                $pkey->finish;
+                last;
+             }
+             else {
+                $PK = $next->{attname};
+             }
+        }
+        
+        $sql .= ' returning ' . $PK;
+        
             eval {
-            return $self->pg->db->query($sql, @bind_params)->hash->{$pkey->{attname}};
+            return $self->pg->db->query($sql, @bind_params)->hash->{$PK};
             };
         } else {
         # delete/update
@@ -357,6 +372,9 @@ Mojolicious::Plugin::QuickPg - Mojolicious Plugin that provided quick access met
   
   my $one_row = $c->qselect('table_name');
   
+  # quick count
+  $c->qcount('table_name', {name => {like => 'Mos%'} } );
+  
   # quick insert
   # returns value of primary key (like as last_insert_id on MySQL)
   
@@ -390,17 +408,42 @@ Mojolicious::Plugin::QuickPg - Mojolicious Plugin that provided quick access met
 =head1 DESCRIPTION
 
 L<Mojolicous::Plugin::QuickPg> is a plugin for Mojolicious apps thas provide simple access to L<Mojo::Pg>.
-The most part of the code for plugin is taken from Dancer::Plugin::Database::Core::Handle (under Artistic License)
+The most part of the code for plugin is taken from L<Dancer::Plugin::Database::Core::Handle> (under Artistic License)
 
 =head1 HELPERS
 
-L<Mojolicious::Plugin::QuickPg> contains next helpers: I<qselect>, I<qinsert>, I<qupdate>, I<qdelete>, I<qcustom>, I<qerror>.
+L<Mojolicious::Plugin::QuickPg> contains next helpers: I<qselect>, I<qinsert>, I<qupdate>, I<qdelete>, I<qcustom>, I<qerror>,
+I<qcount>.
 
 =head2 C<qselect>
 
 my $one_row = $c->qselect('table_name', {id => 1},
                          { order_by => {desc => 'id'}, limit => 10, offset => 5, columns => qw[id name]});
 
+For more examples see /examples/*
+
+=head2 C<qinsert>
+
+For examples see /examples/* 
+
+=head2 C<qupdate>
+
+For examples see /examples/*
+
+=head2 C<qdelete>
+
+For examples see /examples/*
+
+=head2 C<qcustom>
+
+For examples see /examples/*
+
+=head2 C<qcount>
+
+For examples see /examples/* 
+
+=head2 C<qerror>
+
 For more examples see /examples/* 
 
 =head1 CONFIG
@@ -448,18 +491,18 @@ Sebastian Riedel <sri@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-mojolicious-plugin-quickpg at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.htMail?Queue=Mojolicious-Plugin-QuickPg>.  We will be notified, and then you'll
+the web interface at L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Mojolicious-Plugin-QuickPg>.  We will be notified, and then you'll
 automatically be notified of progress on your bug as we make changes.
 
 =over 5
 
 =item * Bitbucket
 
-L<https://bitbucket.org/pkuptsov/mojo-pg-quick>
+L<https://bitbucket.org/pkuptsov/mojolicious-plugin-quickpg>
 
 =item * RT: CPAN's request tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.htMail?Dist=Mojolicious-Plugin-QuickPg>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Mojolicious-Plugin-QuickPg>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
